package services

import (
	"sparrow/pkg/models"
	"sparrow/services/knowoapi/model"
)

// DeviceService device service接口
type DeviceService interface {
	// 获取厂商已经激活的设备总数
	GetDeviceCount(vendorid uint) (int, error)
	//返回厂商某天激活的设备数
	GetActiveNumberOfDate(vendor uint, datetime string) (int, error)
	//获取厂商某天活跃的设备数
	GetLivelyCountOfDate(uint, string) (int, error)
	//获取近N日激活设备数据
	GetActiveOfNumDays(uint, int) ([]map[string]interface{}, error)
	//获取近N日活跃设备数据
	GetLivelyOfNumDays(uint, int) ([]map[string]interface{}, error)
	//获取已经激活的设备列表
	GetDevices(vendorid uint, proid, pi, ps int, deviceid string) ([]models.Device, int, error)
}

type deviceservice struct {
	models *model.All
}

// NewDeviceService create device service
func NewDeviceService(models *model.All) DeviceService {
	return deviceservice{
		models: models,
	}
}
func (a deviceservice) GetDevices(vendorid uint, proid, pi, ps int, deviceid string) ([]models.Device, int, error) {
	return a.models.Device.GetDevices(vendorid, proid, pi, ps, deviceid)
}
func (a deviceservice) GetDeviceCount(vendorid uint) (int, error) {
	return a.models.Device.GetDeviceCount(vendorid)
}
func (a deviceservice) GetActiveNumberOfDate(vendorid uint, datetime string) (int, error) {
	return a.models.Device.GetActiveNumberOfDate(vendorid, datetime)
}
func (a deviceservice) GetLivelyCountOfDate(vendorid uint, datetime string) (int, error) {
	return a.models.Device.GetLivelyCountOfDate(vendorid, datetime)
}
func (a deviceservice) GetActiveOfNumDays(vendorid uint, days int) ([]map[string]interface{}, error) {
	return a.models.Device.GetActiveOfNumDays(vendorid, days)
}
func (a deviceservice) GetLivelyOfNumDays(vendorid uint, days int) ([]map[string]interface{}, error) {
	return a.models.Device.GetLivelyOfNumDays(vendorid, days)
}
